
!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
!MODULE FOR EXTRACTING MET_DATA AND PROFILE DATA FROM TRAJECTORY AND MET-ARCHIVE FILES (FNL OR GDAS)
!THE CODE USES PROFILE.EXE ALONG WITH METEOROLOGICAL FIELDS FROM WWW.ARL.NOAA.GOV/READY.HTML
!BY PETER TUNVED, ITM, 2010	
!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
		
	module MET_PROFILE

	use global_dyn
	use dflib
	USE IFPORT
	
 



	implicit none

	public :: profiler

	contains
	subroutine Profiler(filename_traj, metdata, jold,precip, upperlimit, interpol_const, j, WS_IND, loopind)
INTEGER(KIND=INT_PTR_KIND( )) handle  
INTEGER(4) length
	 INTEGER*4 iresult
	integer, dimension(3) :: kd
	integer :: j, l, jold, year_num, loopind, offset, hour_num, start, ch, ru, pp
	character :: lato*25, longo*25,  year*4, filename_traj*40, met_archive*3, offs*25, w*1
	real(real_x) :: temp1, temp2, rh1, rh2, press1, press2, boundary1, boundary2,  interpol_const, altitude1, altitude2, pot_temp1, pot_temp2, rh_n, precip, upperlimit, &
					WS_IND
	real(real_x), dimension(241, 20) :: metdata
	real(real_x) :: cloudiness, preck, size
	TYPE (FILE$INFO) info 
	real(real_X), dimension(30) :: prof_data_old

	
		
		lat=metdata(j, 10)														!LATITUDE
		longi=metdata(j, 11)														!LONGITUDE

		temp1=metdata(j,15 ) 
		temp2=metdata(j-1, 15)
		temp=temp1+(-temp1+temp2)*interpol_const								!TEMP IN k

		pot_temp1=metdata(j, 14)
		pot_temp2=metdata(j-1, 14)
		pot_temp=pot_temp1+(-pot_temp1+pot_temp2)*interpol_const				!POT TEMP IN K
	
		boundary1=metdata(j, 17)
		boundary2=metdata(j-1, 17)
		bound_act=boundary1+(-boundary1+boundary2)*interpol_const
		boundary=boundary1+(-boundary1+boundary2)*interpol_const
		
		
		if (boundary<250) boundary=250
		!if (cloud_top>boundary) boundary=cloud_top+1 ! adjust boundary layer height during occasions when cloud fills both layers 
		!MIXINGLAYER HEIGHT

	if (boundary==0) boundary=250
		rh1=metdata(j, 18)/100
		rh2=metdata(j-1, 18)/100
		rh=rh1+(-rh1+rh2)*interpol_const
		rh_n=rh*100																!RELATIVE HUM. IN %
		
		press1=metdata(j, 13)*100
		press2=metdata(j-1, 13)*100
		press=press1+(-press1+press2)*interpol_const							!PRESSURE IN Pa
	
		altitude1=metdata(j, 12)
		altitude2=metdata(j-1, 12)
		altitude=altitude1+(-altitude1+altitude2)*interpol_const				!M AGL
		
		
		kd=maxloc(metdata(:, 17), dim=1)
		upperlimit=metdata(kd(1), 17)											!UPPERLIMIT: DEFINED BY MAX MIXINGLAYER HEIGHT DDURING SIMULATION

	
																				!SETS PRECIPITATION RATE. FREQUENCY OF PRECIPITATION DETERMINED BY TRAJECTORY FILE
																!THIS IS TO ACCOUNT FOR THE LARGE GRIDS USED IN THE METDATASET 
		if (j<jold) then
		precip=metdata(j, 16)
		jold=j
		end if

     
    
		year=filename_traj(2:5) !YEAR AS A STRING

		month=int(metdata(j, 4)) !MONTH IN SIMULATION
		day=int(metdata(j, 5)) !DAY OF MONTH INSIMULATION
		year_num=int(metdata(j, 3)) !YEAR IN SIMULATION (AS NUM)
		hour_num=int(metdata(j, 6)) !hour of simulation

		met_archive='GDS'

		!A MET_PROFILE IS EXTRACTED EVERY 4:th HOUR. IT CAN BE EXTRACTED FROM GDAS MET FILE OR FROM FNL DATA
		if ((WS_IND==0 .and. loopind==1) .or. tot_time==timestep) then

        new_met=1

		select case(met_archive)

		case('GDS')

		Write(longo, * ) longi !converts longi{num} to string
		write(lato, *) lat	!converts lat{num} to string

		if (day<8) then
		w='1'
		start=1
		elseif (day>7 .and. day<15) then
		w='2'
		start=8
		elseif (day>14 .and. day<22) then
		w='3'
		start=15
		elseif (day>21 .and. day<29) then
		w='4'
		start=22
		else
		w='5'
		start=29
		
		endif
	
		offset=(day-start)*24+hour_num

write(offs, *) offset

		if (offset<100 .and. offset>9)  ru=system('profile -dF:/working/ -fgdas1.' //manmat(month)//year(3:4)// '.w'//w// ' -y' //lato(4:10)// ' -x' //longo(4:10)// ' -o' //offs(11:14)// '')
		if	(offset>100) ru=system('profile -dF:/working/ -fgdas1.' //manmat(month)//year(3:4)// '.w'//w// ' -y' //lato(4:10)// ' -x' //longo(4:10)// ' -o' //offs(10:14)// '')
		if (offset<10)  ru=system('profile -dF:/working/ -fgdas1.' //manmat(month)//year(3:4)// '.w'//w// ' -y' //lato(4:10)// ' -x' //longo(4:10)// ' -o' //offs(12:14)// '')


		open(unit=17, file="profile.txt")
	
        handle = FILE$FIRST 
		iresult = GETFILEINFOQQ("profile.txt",info,handle) 
		if( iresult.NE.0 ) THEN 
		SIZE=info.length 
		ELSE 
		SIZE=0 
		END IF

		if (size .GT. 1800) then
		do l=1, 11
		read(unit=17, fmt=*)
		end do
		read(unit=17, fmt=*) prof_data
		prof_data_old=prof_data
        C_C=prof_data(28)/100
    
		do l=1, 3
		read(unit=17, fmt=*)
		end do

		READ(17, fmt=*) (vert_prof(j, :), j=1, 22)
        vert_prof_old=vert_prof
		cloud_base=0
		cloud_top=0
		
		if (C_C>0) then
		do ch=1,10

		  
			if (vert_prof(ch, 7)>95 .and. ch>1) then   ! find cloud levels in lower 10 layers of atmosphere
			
		

		  

		    if (cloud_base==0 .and. vert_prof(ch, 2)>0) then
			
		    cloud_base=vert_prof(ch, 2)
		    
		    T_base=vert_prof(ch, 3)+273.15
		    P_base=vert_prof(ch, 1)
		    
		    

	        end if
           
		     goto 24
		    end if
		   end do
		  end if
		  
		   24 continue
		          
		   
		    if (cloud_top==0 .and. cloud_base>0) then    		 
		
		    do pp=ch, 10
		    
		    if (vert_prof(pp, 7)>95 .and. vert_prof(pp-1, 7)>95 ) then
		    cloud_top=vert_prof(pp, 2)
		    end if
		    end do
		    end if

	

			123 continue
		else 
		prof_data=prof_data_old
		vert_prof=vert_prof_old
		end if




!if (cloud_top>upperlimit) cloud_top=upperlimit-10
!if (cloud_top>boundary) boundary=cloud_top+1

	close(17)

		case('FNL')

		Write(longo, * ) longi !converts longi{num} to string
		write(lato, *) lat	!converts lat{num} to string

		if (day<16) then
		start=1
		offset=(day-start)*24+hour_num
		ru=system('profile -dC:/working/ -fFNL.NH.' //manmat(month)//year(3:4)// '.001 -y' //lato(4:10)// ' -x' //longo(4:10)// ' -o' //offs(10:14)// '')
		elseif (day>15) then
		start=16
		offset=(day-start)*24+hour_num
		write(offs, *) offset
		ru=system('profile -dC:/working/ -fFNL.NH.' //manmat(month)//year(3:4)// '.002 -y' //lato(4:10)// ' -x' //longo(4:10)// ' -o' //offs(10:14)// '')
		end if

		open(unit=17, file="profile.txt")
	
        handle = FILE$FIRST 
		iresult = GETFILEINFOQQ("profile.txt",info,handle) 
		if( iresult.NE.0 ) THEN 
		SIZE=info.length 
		ELSE 
		SIZE=0 
		END IF
		
		if (size .GT. 1800) then
		do l=1, 10
		read(unit=17, fmt=*)
		end do
		read(unit=17, fmt=*) prof_data
		prof_data_old=prof_data
	
		else 
		prof_data=prof_data_old
		end if
	
		end select
		

	
		end if



		end subroutine profiler
		end module MET_PROFILE