module emissions

use global_dyn


	implicit none

	public :: terp_em, trans, emep_em, dominating_class, PAR_flux, sea_salt_emission, DMS

	contains


	subroutine terp_em(lat, longi, terpene_em1,terpene_em2, &
					   sesq_em, temp, boundary, igbplat, igbplong, ppfd, ppfd_diff)
	!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%!
	!CALCULATES THE EMISSION OF ISOPRENE (MONSON ET AL., 1994) AND MONOTERPENES AND		!	
	!SESQUITERPENES USING BIOMASSDENSITIES AS ESTIMATED BY GUENTHER ET AL., 1995		!
	!PETER TUNVED, ITM, 2010															!
	!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


	integer ::	ii, j, k, l, jko
	real(real_x) ::	lat, longi, temp, boundary, yterp,y_sesqi, biomass1, biomass2, empot, &
				terpene_em1,terpene_em2, sesq_em, empot_sesq_mixed, zenith, ppfd, ppfd_diff, yiso, &
				alfa_iso, CL1, CT1, CT2, CT3, TM, CL, CT, isoprene_em, em_pot_conifers,em_pot_iso_conifers, &
				em_pot_iso_decid, em_pot_iso_mixed, GVI, GVI_max, empot_pine, empot_spruce

	real(real_x), dimension(10) :: Dm, G2, Dr, NPP,  D_p, cover, empotall, empotisop
	real(real_x), dimension(720) :: igbplat
	real(real_x), dimension(1440) :: igbplong
	real(real_x), dimension(12), parameter :: &
	sesq=(/ 0.0e0, 0.0e0 ,0.0e0, 16.e-3,	55.0e-3,	137.0e-3,	425.5e-3,	104.5e-3,	17.5e-3,	27.0e-3, 0.0e0, 0.0e0 /)
	character input*20



		!BELOW PERCENTAGE LAND COVER DATA FOR 10 DIFFERENT ECOSYSTEM TYPES IS READ IN
		do k=1, 720
		if ((abs(lat-igbplat(k)))<0.25) then
		goto 1000
		end if
		end do
		1000 continue

		do l=1, 1440
		if ((abs(longi-igbplong(l)))<0.25) then
		goto 1001
		end if
		end do
		1001 continue

		cover(1)=needleleafes(k, l)
		cover(2)=evergreenbroad(k, l)
		cover(3)=deciduousbroad(k, l)
		cover(4)=decideuousneedle(k, l)
		cover(5)=mixedforest(k, l)
		cover(6)=openshrubs(k, l)
		cover(7)=closedshrubs(k, l)
		cover(8)=grasslands(k, l)
		cover(9)=permanentwetlands(k, l)
		cover(10)=croplands(k, l)


		cover=cover/100 !COVER 0-1


		!CALCULATES THE FLUX OF PHOTOSYNTHETICAL ACTIVE RADIATION
		call PAR_flux(ppfd, ppfd_diff)

		! NDVI DATA FROM GIMMS (2002) DETRMINED (Guenther et al 1995 for details)
 
   		do k=1, 360
		if (int(lat)==int(lats(k))) then
		goto 8000
		end if
		end do
		8000 continue
   

		do l=1, 720
		if (int(longi)==int(longs(l))) then
		goto 8001
		end if
		end do
		8001 continue


		GVI=100*(NDVI(l, k)+1)
		GVI_max=100*(NDVIMAX(l, k)+1)

		!NET PRIMARY PRODUCTION
		NPP(1)=BIOTABLE(1,3)
		NPP(2)=BIOTABLE(2, 3)
		NPP(3)=BIOTABLE(3, 3)
		NPP(4)=BIOTABLE(4, 3)
		NPP(5)=BIOTABLE(5, 3)
		NPP(6)=BIOTABLE(6, 3)
		NPP(7)=BIOTABLE(7, 3)
		NPP(8)=BIOTABLE(8, 3)
		NPP(9)=BIOTABLE(9, 3)
		NPP(10)=BIOTABLE(10, 3)

		
		G2(1)=BIOTABLE(1,4)
		G2(2)=BIOTABLE(2, 4)
		G2(3)=BIOTABLE(3, 4)
		G2(4)=BIOTABLE(4, 4)
		G2(5)=BIOTABLE(5, 4)
		G2(6)=BIOTABLE(6, 4)
		G2(7)=BIOTABLE(7, 4)
		G2(8)=BIOTABLE(8, 4)
		G2(9)=BIOTABLE(9, 4)
		G2(10)=BIOTABLE(10, 4)

		Dr(1)=BIOTABLE(1,5)
		Dr(2)=BIOTABLE(2, 5)
		Dr(3)=BIOTABLE(3, 5)
		Dr(4)=BIOTABLE(4, 5)
		Dr(5)=BIOTABLE(5, 5)
		Dr(6)=BIOTABLE(6, 5)
		Dr(7)=BIOTABLE(7, 5)
		Dr(8)=BIOTABLE(8, 5)
		Dr(9)=BIOTABLE(9, 5)
		Dr(10)=BIOTABLE(10, 5)
		
		!EMISSION POTENTIAL
		EmPotall(1)=1.5 !BIOTABLE(1,2)
		EmPotall(2)=BIOTABLE(2, 2)
		EmPotall(3)=BIOTABLE(3, 2)
		EmPotall(4)=BIOTABLE(4, 2)
		EmPotall(5)=1.5 !BIOTABLE(5, 2)
		EmPotall(6)=BIOTABLE(6, 2)
		EmPotall(7)=BIOTABLE(7, 2)
		EmPotall(8)=BIOTABLE(8, 2)
		EmPotall(9)=BIOTABLE(9, 2)
		EmPotall(10)=BIOTABLE(10, 2)
		
		empotisop(1)=0.1 !BIOTABLE(1,1)
		empotisop(2)=8 !BIOTABLE(2, 1)
		empotisop(3)=8 !BIOTABLE(3, 1)
		empotisop(4)=8 !BIOTABLE(4, 1)
		empotisop(5)=8 !BIOTABLE(5, 1)
		empotisop(6)=8 !BIOTABLE(6, 1)
		empotisop(7)=8 !BIOTABLE(7, 1)
		empotisop(8)=8 !BIOTABLE(8, 1)
		empotisop(9)=8 !BIOTABLE(9, 1)
		empotisop(10)=2 !BIOTABLE(10, 1)

		D_p=Dr*NPP

		!CALCULATES FOLIAR BIOMASS DENSITY
		do k=1, 10
		if (G2(k)<GVI) then
		Dm=D_p*(exp(log(2.)*((GVI-G2(k))/(GVI_max-G2(k))))-1)
		else
		dm(k)=0
		endif
		enddo

		empotisop(1)=0.38*0.89
		empotisop(5)=1.
		empot_spruce=1.5 !EMISSION POTENTIAL OF SPRUCE

		!Seaononal dependence on emission potentials from Towards a comprehensive emission inventory
		!of terpenoids from boreal ecosystems by Tarvainen et al., 2007
		
		empot_pine=1.5
		if (month<2 .or. month>10) then
		empot_pine=1.5
		elseif (month>3 .and. month<7) then
		empot_pine=2.39
		elseif (month>6 .and. month<11) then
		empot_pine=1.46
		endif


		empotall(1)=0.54*empot_pine+0.46*empot_spruce
		empotall(5)=0.44*empot_pine+0.38*empot_spruce+0.18*1


		yterp=exp(0.09*(temp_surf-303.0)) !TEMPERATURE CORRECTION OF MONOTERPENE EMISSIONS
		
		terpene_em=(timestep/3600)*1e-6*1e-6*6.022e23*(sum(dm*cover*empotall*yterp))/(boundary*136)

		em_pot_conifers=2. !ug/(g(ldw)*h)
   
	
		!Effective emission potenital of mixed forest, i.e. combination of spruce, 
		!pine and decidous "high isoprene" and "low isoprene" emitters 
		empot=0.18*(0.098*1+0.92*0.3)+0.82*em_pot_conifers
		empot_sesq_mixed=0.18*4+0.82*sesq(month) !Hakola et al., 2001, Bor: env. Res.
   
		!below for calculation of sesquiterpene emissions. Em. potential dependent on season. Read from sesq
		y_sesqi=exp(0.19*(temp_surf-303.0)) 
		sesq_em=(timestep/3600)*1e-6*1e-6*6.022e23*((sesq(month)*dm(1)*cover(1)*y_sesqi+dm(5)*cover(5)*empot_sesq_mixed*y_sesqi))/(boundary*204)
		
		!Isoprene emissions calculated following Monson, R.K., Harley, P.C., Litvak, M.E., Wildermuth, M.,
		!Guenther, A.B., Zimmermann, P.R., Fall, R., 1994. Environmental
		!and developmental controls over the seasonal pattern
		!of isoprene emission from aspen leaves. Oecologia 99,
		!260}270.

		alfa_iso=0.0027
		CL1=1.066
		CT1=95000.
		CT2=230000.
		CT3=0.061
		TM=314.

		CL=alfa_iso*CL1*(ppfd+ppfd_diff)/(sqrt(1+alfa_iso**2.*(ppfd+ppfd_diff)**2))
		CT=exp((CT1*(temp-303.))/(r_g*303.*temp_surf))/(CT3+exp((CT2*(temp_surf-TM)))/(r_g*303.*temp))
		yiso=CL*CT
		em_mat(6)=(1./3600.)*1e-6*1.e-6*6.022e23*sum((empotisop*dm*cover*yiso))/(boundary*68.)
		
		
		end subroutine terp_em


	subroutine dominating_class(lat, longi, igbplat, igbplong)
	!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! 
	!!Get the dominating land use type in the grid point!!
	!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	integer :: k, l
	real(real_x), dimension(720) :: igbplat
	real(real_x), dimension(1440) :: igbplong
	real(real_x) :: lat, longi

	
	
	do k=1, 720
	if ((abs(lat-igbplat(k)))<0.25) then
	goto 1000
	end if
	end do
	1000 continue

	do l=1, 1440
	if ((abs(longi-igbplong(l)))<0.25) then
	goto 1001
	end if
	end do
	1001 continue

	dom_class=domclass(k,l)+1

	end subroutine dominating_class
			
	subroutine 	emep_em(sox_em, nox_em, co_em, nmvoc_em, sox_s11, pm25em)
	!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	! calculate emissions of so2,nox, nmvoc, co from the emep expert emissions.
	! trajectory endpoints are recalculated to the emep grid using trans. Emissions given
	! as Mg/grid square and year. Flat emissions.
	!PETER TUNVED, ITM, 2010
	!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	integer :: apa, p, o, x, y, inder, sp, kpp
	real(REAL_X) ::  so2em, noxem, coem, nmvocem, so2_s11, pm25
	real(real_x), dimension(16250, 3) :: sox_em
	real(real_x), dimension(16250, 3) :: nox_em
	real(real_x), dimension(16250, 3) :: co_em
	real(real_x), dimension(16250, 3) :: nmvoc_em
	real(real_x), dimension(16250, 3) :: sox_S11
	real(real_x), dimension(16250, 3) :: pm25em
	real(real_x) :: snap	



	!%%%%%Convert coordinates in decimal form to "lat.minutes"%%%
	x=abs(longi-int(longi))*0.6+int(longi)
	y=abs(lat-int(lat))*0.6+int(lat)
	call trans(x,y)

	!EMEP EMISSIONS USING THE EMEP GRID. EACH GRID IS SCALED TO CORRESPONDING 
	!GRID AREA USING GRID ALL. GIRD AREA TYPICALLY VARIES BETWEEN 1200-2800 sqkm

	do p=1, 16249

	if (int(sox_em(p, 1))==x .and. int(sox_em(p, 2))==y) goto 11

	end do

	11 continue

	if (p<=16249 .and. grid_all(p, 3)>0) then
	so2em=1.e-6*1.e6*6.022e23*sox_em(p, 3)/(grid_all(p, 3)*1.e6*365.*24.*3600.*64.*boundary)
	so2_S11=1.e-6*1.e6*6.022e23*sox_S11(p, 3)/(grid_all(p, 3)*1.e6*365.*24.*3600.*64.*boundary)
	noxem=1.e-6*1.e6*6.022e23*nox_em(p, 3)/(grid_all(p, 3)*1.e6*365.*24.*3600.*46.*boundary)
	coem=1.e-6*1.e6*6.022e23*co_em(p, 3)/(grid_all(p, 3)*1.e6*365.*24.*3600.*28.*boundary)
	nmvocem=1.e-6*1.e6*6.022e23*nmvoc_em(p, 3)/(grid_all(p, 3)*1.e6*365.*24.*3600.*30.*boundary)

	em_mat(5)=nmvocem
	em_mat(4)=coem
	em_mat(1)=noxem
	em_mat(2)=noxem
	em_mat(3)=so2em
	
	end if

	end subroutine emep_em

			


	subroutine PAR_flux(ppfd,ppfd_diff)


!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
!details in http://rredc.nrel.gov/solar/pubs/spectral/model/section2.html and Alados-Arboledas et al.,!
!Agricultural and Forest Meteorology 101 (2000) 187:201												  !	
!Beam irradiance (Rni) is given by:																	  !
! Rni=cos(zenith).*Rci.*tauOI.*tauRI.*tauAI															  !
!where:																								  !	
!Rci=extraterrestial irradiance																		  !
!integrated transmittances for:																		  !
!tauOI=ozone absorption																				  !
!tauRI=rayleigh scattering																			  !
!tauAI=aerosol particles																			  !
!tauWI=water vapour (relevant only for longwave radiation)		

!diffuse radiation is calculated according to

!Rd=Rdri+Rdai+Rdmi
!where:
!Rdri is scattering by air molecules
!Rdai is scattering by aerosols
!Rdmi is multiple scattering between surface and atmosphere	
!PETER TUNVED, ITM, 2010										  !
!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	integer :: j, a
	real(real_x) :: tauOI, tauRI, tauAI, tauWI, P0,a_m,a_m1, mPrim, h0, O_3,Mo,alpha_aer,beta, omega, &
					tauAIprim,Rni, Fr, Fa,rhoG, tauRIprim,Faprim,tauASI,tauASIprim, tauAAI, tauAAIprim, &
					rhoSI, Rdri, Rdai, Rdmi, Rd, Rdir, Rdiff,P, lambda, rci, zenith, ppfd_diff, ppfd, a_lambda




	ppfd=0
	ppfd_diff=0
	if (zenith_angle<90) then
  
	do a=1,15

	lambda=sol_info(a, 1)*1.e-3
	a_lambda=sol_info(a,5)
	Rci=sol_info(a, 10)
	zenith=zenith_angle*pi/180.
	P=press
	P0=101325.


	a_m1=1/(cos(zenith)+0.15*(93.885-zenith)**-1.253) 
	!optical airmass according to Kasten, F., "A New Table and Approximate Formula 
	!for Relative Optical Air Mass," Arch. Meteorol. Geophys. Biochlimatol., 
	!Ser. B14, 1966, pp. 206-223.

	!where: 
	!a_m is the optical airmass
	!lambdaEFF is the effective wavelength
	!alpha and beta is dependent on aerosol parameters
	!and mPrim is pressure corrected optical airmass



	a_m=(1.002432*cos(zenith)**2.+0.148386*cos(zenith)+0.0096467)/(cos(zenith)**3.+0.149864*cos(zenith)**2.+0.0102963*cos(zenith)+0.000303978)
	!above expression from Young, A. T. 1994. Air mass and refraction. Applied Optics. 33:1108,1110.


	mPrim=P/P0*a_m

	!rayleigh portion according to Kneizys, F. X., E. P. Shettle, ...
	!W. O. Gallery, J. H. Chetwynd, Jr., L. W. Abrea, J. E. A. Selby,...
	!R. W. Fenn, and R. W. McClatchey, Atmospheric Transmittance/Radiance: 
	!Computer Code LOWTRAN5, Tech. Rep. AFGL-TR-800067, Bedford, MA: U.5. Air 
	!Force Geophysics Laboratory, 1980. 

	tauRI=exp(-mPrim/(lambda**4*(115.6406-1.335/lambda**2)))

	! the ozon absorption portions is estimated accrding to Leckner, B., 
	!"The Spectral Distribution of Solar Radiation at the Earth's Surface: 
	!Elements of a Model," Solar Energy, Vol. 20, 1978, pp. 143-150.

	h0=22.

	O_3=0.3
	Mo=(1.+h0/6370.)/(cos(zenith)**2.+2.*h0/6370.)**0.5
	tauOI=exp(-a_lambda*O_3*Mo)

	!where a_lambda is ozone absorption coefficient at wavelenght i
	!O3 the ozone amount (atm-cm)
	!h0=height of ozone maximum in km (22?)
	!and Mo ozone mass


	!aerosol properties

	alpha_aer=0.7 !assuming ngstrm exponent of 0.7
	beta=0.1 ! assuming turbididty coefficient of 0.1
	omega=0.8 ! assuming single scattering albedo of 0.8



	tauAI=exp(-mPrim*beta*lambda**-alpha_aer)

	tauAIprim=exp(-1.66*beta*lambda**-alpha_aer)

	Rni=cos(zenith)*Rci*tauOI*tauRI*tauAI !*tauWI*


	!diffuse radiation is calculated according to

	!Rd=Rdri+Rdai+Rdmi

	!where:
	!Rdri is scattering by air molecules
	!Rdai is scattering by aerosols
	!Rdmi is multiple scattering between surface and atmosphere

	Fr=0.5
	Fa=1-exp(-0.6931-1.8326*cos(zenith))

	!rhoG is from tabulated values

	rhoG=0.4
	tauRIprim=exp(-1.66/(lambda**4.*(115.6406-1.335/lambda**2.)))
	Faprim=1-exp(-0.6931-1.8326*cos(0.92))

	tauASI=exp(omega*log(tauAI))
	tauAAI=tauAI/tauASI

	tauASIprim=exp(omega*log(tauAIprim))
	tauAAIprim=tauAIprim/tauASIprim

	rhoSI=((1-Fr)*(1-tauRIprim)+(1-Faprim)*(1-tauASIprim)*tauRIprim)*tauAAIprim

	!prim indicate calculated values at air mass 1.66


	Rdri=Fr*tauOI*tauAAI*(1-tauRI)*Rci*cos(zenith)
	Rdai=Fa*tauOI*tauRI*(1-tauASI)*Rci*cos(zenith)

	Rdmi=rhoG*rhoSI*(Rni*cos(zenith)+Rdai+Rdri)/(1-rhoG*rhoSI)

	!where:
	!Fr is forward scattering due to rayleigh processes
	!Fa is forward scattering due to aerosol scattering (Assumed wevelenght independent)
	!rhoG is the surface albedo
	!rhoSI is the sky albedo
	!where
	!aai=aerosol transmittance due to aerosol absorption 
	!asi=----------"------------------ aerosol scattering

	!and


	!where omega is the single scattering albedo


	!diffuse radiation is calculated according to

	Rd=Rdri+Rdai+Rdmi
	!Rdir = .*(exp(-0.185.*mPrim)).*(cos(zenith))
	!Rdiff = 0.4.*(1-Rdir).*(cos(zenith))
	ppfd=ppfd+Rni
	ppfd_diff=ppfd_diff+Rd


	end do

	end if
	end subroutine PAR_flux



	  subroutine trans(ei, ej)
	  !%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%!
	  !TRANSFORMS LAT-longi PAIRS TO EMEP EMISSION COORDINATES. ADOPTED FROM			!
	  !WWW.EMEP.INT																	!
	  !%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	  integer ::  ei, ej
	  real(real_x), parameter :: PI = 3.1415926535897932384    ! 4 * atan2(1,1)
	  real(real_x), parameter :: R = 6370.0 ! earth radius in km

	  !defaults of emep official 50km grid
	  real(real_x) :: lambda0 = -0.55850536063818546460 ! -32. * PI/180
	  real(real_x) :: phi0 = 1.04719755119659774614 ! 60 * PI/180
	  real(real_x) :: x0 = 8.0
	  real(real_x) :: y0 = 110.0  
	  real(real_x) :: d = 50.0 ! grid-length at PHI0
	  real(real_x) :: mapping = 237.73163644213748359595 ! R / d * (1 + sin(phi0))
	  real(real_x) ::  rlong, rlat, ex, ey, tn


    
		rlong = pi/180*(longi)
		rlat = pi/180*(lat)
		tn = sin((PI/2 - rlat)/2)/ cos ((PI/2-rlat)/2)
		ex = X0 + mapping * tn * sin(rlong - LAMBDA0)
		ey = Y0 - mapping * tn * cos(rlong - LAMBDA0)



		ei = nint(ex)
		ej = nint(ey)
		end subroutine



		subroutine sea_salt_emission(SS_params, Tw, ice_data, SST)
		!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%!
		!ESTIMATES THE FLUX OF SEASALTPARTICLES FROM THE OCEAN. DEPENDENT ON WINDS- !
		!AND TEMPERATURE. IN CURRENT SETUP TREATED AS SULFATE (FROM MARTENSSON ET AL!
		!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

		integer :: a, B, lat_x, long_x

		real(REAL_X) :: Dp, Tw, dfdlogdp, Bk, Ak, W, dlogdp, ice

		real(real_x), dimension(5) :: C_mat, D_mat

		real(real_x), dimension(3, 12) :: SS_params

		real(real_x), dimension(2160, 360) ::	ice_data, SST
		real(real_x), dimension(180, 360) ::	ice_extract, SST_extract


		lat_x=90-int(lat)
		long_x=180+int(longi)


		
		ice_extract=ice_data(180*(month-1)+1:180*(month-1)+180, :)
		SST_extract=SST(180*(month-1)+1:180*(month-1)+180, :)
		!ice_data_extract=

		ice=ice_extract(lat_x, long_x)/100

		Tw=273.15+SST_extract(lat_x, long_x)/100
	

		if (tw<273.15) then
		tw=273.15
	end if
if (ice>1) then
ice=1
end if

		W=(3.84e-4*wind_speed**3.41)/100. !White capped fraction
 


		do a=1, sections
   
		 Dp=rdry(a)*2.
		dlogdp=(log10(2.*rdry(11))-log10(2.*rdry(10)))

    
		if (Dp>20.e-9) then
		do B=1,3
		if (Dp>1e-6*ss_params(B, 1) .and. Dp<=1e-6*ss_params(B, 2)) then
        C_mat=ss_params(B, 3:7)
        D_mat=ss_params(B, 8:12)
		end if
		end do

		Ak=C_mat(1)*Dp**4+C_mat(2)*Dp**3+C_mat(3)*Dp**2+C_mat(4)*Dp+C_mat(5)
		Bk=D_mat(1)*Dp**4+D_mat(2)*Dp**3+D_mat(3)*Dp**2+D_mat(4)*Dp+D_mat(5)
		dFdlogdp=dlogdp*((Ak*Tw+Bk)*W)/boundary
		
		!Add the sea salt as sulfate
		n_conc(a)=n_conc(a)+(1-ice)*dfdlogdp*timestep
		vol_conc(a, 1)=vol_conc(a, 1)+(1-ice)*timestep*scale**3*dfdlogdp*rdry(a)**3*4.*pi/3


		end if
		end do

		end subroutine


		subroutine DMS(dms_flux)
		!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
		!ESTIMATE THE FLUX OF DMS FROM THE SEASURFACE. SEASONALLY DEPENDENT, MONTHLY VALUES USED OF !
		!DMS SURFACE CONCENTRATION																	!
		!%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%!
		
		integer :: inder, p	
		real(real_x) :: uten, schmidt, ratio, kw, dms_water
		real(real_x), dimension(64800, 14) :: dms_flux

		inder=0
		DMSflux=0
		dms_water=0

		do p=1, 64800
		if (int(DMS_flux(p, 1))==int(lat) .and. int(DMS_flux(p, 2))==int(longi)) then
		inder=inder+1
		DMS_water=DMS_water+DMS_flux(p, month+2)*62. !ng/l. DMS water concentration
		end if
		end do

		if (DMS_water>0) then
		DMS_water=DMS_water/inder
		end if

		UTEN=wind_speed !m/s
		SCHMIDT=2674.-147.12*(temp_surf-273.0) +13.726*((temp_surf-273.0)**2) -20.038*((temp_surf-273.0)**3)
		!SCHMIDT at sea surface T by
		!SCHMIDT at 20 degrees=600
		RATIO=SCHMIDT/600.
		KW=0.222*(UTEN**2)+0.333*UTEN
		KW=KW*(RATIO**(-0.5))
		DMSFLUX=KW*DMS_water

		!Convert into kg  DMS s-1 m-2
		!(/3600 converts hour-1 --> s-1; /1.0E12 ng --> kg)
		!(divide by 100 convert cm to m *1000 convert dm-3 to m-3)
		DMSFLUX=1e-6*((DMSFLUX/(3600.0*1.E12))*1000/62*6.022e23)/boundary !molecules s-1 cm-3
				  

		end subroutine

		end module emissions