!==================================================================================
! Subroutines and functions to calculate the enhancement factor f for
! <I(T,q)> = f * I(<T>,<q>)
! Lauros et al. (2006): Atmospheric variability and..., Atm. Res., 82, 503-513.
!
! 1/2007 JL
!==================================================================================

MODULE enhfactor

CONTAINS


!----------------------------------------------------------------------------------
FUNCTION factorenh(c_mean,T_mean,q_mean,T_sigma,q_sigma,Tq_corr)
! calculate the enhancement factor
!input q_mean, q_sigma g/kg

	USE commonvar

	IMPLICIT NONE

	INTEGER :: jj
	REAL(real_x), DIMENSION(9,3) :: m_matr
	REAL(real_x) :: c_mean,T_mean,q_mean,T_sigma,q_sigma,Tq_corr,sumterm,factorenh

	m_matr(1,1:3)=(/1.0, 1.0, -1.0 /)
	m_matr(2,1:3)=(/102.167, 75.6275, 5.24575 /)
	m_matr(3,1:3)=(/0.0981002, 0.118522, 0.362437 /)
	m_matr(4,1:3)=(/172.484, 140.574, 35.1342 /) 
	m_matr(5,1:3)=(/-0.563049, -0.669952, -0.544815/)
	m_matr(6,1:3)=(/-0.996978, -1.78544, -0.980970/)
	m_matr(7,1:3)=(/2.06530, 0.0, 0.878959/)
	m_matr(8,1:3)=(/0.0, 1.16715, 0.408232/)
	m_matr(9,1:3)=(/0.0, 0.0, 1.0/)

	sumterm=0.
	DO jj = 1,3
		sumterm=sumterm+factorenhjj(c_mean,T_mean,q_mean,T_sigma,q_sigma,Tq_corr,m_matr(1:9,jj))
		
	END DO

	factorenh=10**(sumterm)

END FUNCTION factorenh

!!----------------------------------------------------------------------------------
!! function for the parametrization
FUNCTION factorenhjj(c_mean,T_mean,q_mean,T_sigma,q_sigma,Tq_corr,m_vec)


	USE commonvar

	IMPLICIT NONE
	REAL(real_x) :: c_mean,T_mean,q_mean,T_sigma,q_sigma,Tq_corr,factorenhjj
	REAL(real_x), DIMENSION (9):: m_vec



	factorenhjj=m_vec(1)* &
	(10.0**(m_vec(2)*T_mean**m_vec(3)-m_vec(4)))* &
	(c_mean**m_vec(5))* &
	(q_mean**m_vec(6))* &
	(T_sigma**m_vec(7))*(q_sigma**m_vec(8))*(Tq_corr**m_vec(9))

!	print*, 'cmean', c_mean
!	print*, 'tmean', T_mean
!	print*, 'qmean', q_mean
!	print*, 'tsigma', T_sigma
!	print*, 'qsigma', q_sigma
!	print*, 'tqcorr', Tq_corr
!	print*, 'factor', factorenhjj
	
END FUNCTION factorenhjj


!----------------------------------------------------------------------------------
FUNCTION testfrules(T,rh,qsq,Ts,qs, Inuc)
! test if the values of variables are valid
!
! T temperature, rh relative humidity
! qsq=qs/q, where q mean value and....
! Ts and qs standard deviations
! Inuc nucleation rate (cm^-3)


	USE commonvar

	IMPLICIT NONE

	REAL(real_x) :: T,rh,qsq,Ts,qs,Inuc
	LOGICAL :: testfrules 

	IF (rh<3. .OR. qsq>.25 .OR. Ts>1. .OR. T<240. .OR. Inuc<1.e-5) THEN
		testfrules=.FALSE.
	ELSE
		testfrules=.TRUE.
	END IF
	
END FUNCTION testfrules

END MODULE enhfactor

