module global_parameters

implicit none


!Size distributon parameters

  integer, parameter :: &
			sections = 45, &			! number of size sections
			modes = 4, &				! number of modes
		
			comp=6

  
  integer, parameter :: &
			cond = 2, &					! number of condensable species
			noncond =1, &				! number of non-condensable species
			compo = cond + noncond		! number of composition classes

  real*8, parameter :: &
			vap_limit = 1.e2, &			! threshold vapour concentration (#/m^3)
			n_limit = 1.d-5				! threshold number concentration (#/m^3) 
										! (below which bin considered empty)


!******************* PROPERTIES OF PARTICULATE COMPOUNDS *******************************
!
!	compounds in order: (1) sulphuric acid
!						(2) insoluble organic vapour
!						(3) non_condensable insoluble compound (e.g. dust)


  real*8, dimension(compo), parameter ::	&
			density = (/ 1830., 1107., 2000./), &	! density (kg/m^3)
			molarmass = (/ 98.08, 186., 12./)		! molar mass (g/mol) 

  real*8, dimension(cond)	:: &
			c_sat = (/ 0.d0, 3.d10 /), &			! saturation concentration above flat surface (#/m^3)
			surf_ten = (/55.d-3, 30.d-3 /), &		! surface tension (N/m)
			diff_vol = (/ 51.96, 51.96 /), &		! diffusion volume (????)
			alpha = (/ 1., 1. /)					! mass accomodation coefficient
			
real*8, dimension(5), parameter ::	&
	em_fac=(/ 2.65, 2.5, 1.9, 1., 1./)

	real*8, dimension(comp), parameter ::	&
			rhomat = (/ 1900., 787., 2000., 2200., 2000., 1900. /), &	
			molmat = (/ 115.d-3, 200.d-3, 12.d-3, 67.d-3, 70.d-3, 115.d-3 /), &
			solmat = (/ 1., 0.1, 0., 1., 0., 1. /), &
			vantmat = (/ 2.4, 1., 0., 2., 0., 2. /)
			
			
			!******************************VARIABLES********************************
			
			
			character (len=3) :: nuc_approach				! for reading which nucleation mechanism used
  
			
			real*8 :: vap_conc(cond), source_strength(cond)
			
			
			
            real*8 :: rh, &
			          temp, &
			          pres, &
			          wind_speed, &
			          MLH
			          
			
			      
			real*8, dimension(56) :: J_values(56)
			      
			real*8 :: timestep
			      
			real*8 :: nh3_mix

real*8, parameter :: &	
			avogadro = 6.0221d23, &   	! Avogadro number (#/mol)
			boltzmann = 1.3807d-23, &	! Boltzmann constant (J/K)
			gravitation = 9.81,	&		! gravitational acceleration (m/s^2)
			pi = 3.1415927, &
			pstand = 1.01325e5, &		! standard pressure (Pa)
			r_g = 8.314, &				! molar gas constant (J/(mol K))	
			zero = 0.0

  real*8, parameter :: &
			molar_h2o = 18.016,		&	! molar mass of water (g/mol)
			molar_air = 28.965,		&	!	- " -	air
			molar_nh3 = 17.03			!	- " -	ammonia

  real*8, parameter :: &			! mass of one molecule (kg)
			molec_h2o = molar_h2o*1.d-3/avogadro, &
			molec_nh3 = molar_nh3*1.d-3/avogadro

  ! mass and volume of one molecule for condensable compounds													
  real*8, dimension(cond), parameter :: &
			molecmass = molarmass(1:cond)*1.d-3/avogadro, &
			molecvol = molecmass/density(1:cond)		

  real*8, parameter :: &
			scale = 1.d6				! scaling factor (m -> um)



!***************************Global variables******************************
 real*8, dimension(sections) :: &
			n_conc,		 &				! number concentration (#/m^3)
			radius,		 &				! actual radii of particles (m)
			rdry,		 &				! dry radii of particles in size sections (m)
			core,		 &				! dry volume of particles (m^3)
			mass,		 &				! mass of particles (m^3)
			uppervol,	 &				! largest possible volume in each section (m^3) 
			lowervol,  	 &				! smallest possible volume in each sections (m^3)
			midvol,      &
			n_coag, &
			n_prim, & 
			mass_prim

	real*8, dimension(sections):: n_nuc
	real*8, dimension(sections, compo) :: vol_nuc, vol_prim
	real*8 :: nuc_rate, n_sa
	
real*8, dimension(sections,compo) :: vol_conc, vol_coag

real*8, dimension(55):: conc1, conc2 
real*8 :: terp_conc, isop

real*8 :: oh,ho2, no3,clavdi, nox, o3,so2, M, no2, no, o2, n2, hcho, ch4, co, nh3,h2o, h2o2_mix, Pso2, Po3, Ph2o2, h2o2 !gas-phase variables
real*8 :: HNO3, HNO2, O, DMS, DMSO, MSA, DMS_FLUX, MONTH, DIACID, OXYPINICACID, SEED1, N2O5, PAN, SO4, CH3O2, CH3OH, HCO, SOURCE_TERM_OH


real*8, dimension(17) :: em_mat, dry_dep_gas


!Variables specififc for JVAL and associated routines below

integer :: testreadhv, startdate, cloud
real*8 :: t_from_start,  zenith_angle, lat, longi

!cloud paramneters

real*8, dimension(sections) :: numbs, radie, activerade, bmat

real*8 :: updrft, alt_thres


!deposition variables
real*8 :: dom_class, boundary, potential_temp_grad, altitude, ustar_bulk2, Ra, ustar, ri, Ra_bulk, dry_dep1
	real*8, dimension(sections) :: n_depo
	real*8, dimension(sections, compo) :: vol_depo			
end module