module photolyzer


use global_parameters
use jval1
implicit none

public :: photolysis

contains

!%%%%%%%%%%%%%%%INITIALIZES THE PHOTOLYSISCONSTANTS ESTIMATES%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	subroutine photo_chem(lsin)

    implicit none

	

	real*8 :: es_T
	real*8 :: jval(56),tt, a, b
	real*8 zen
	integer :: lsin, ii


	es_T=(rh*(1d-3*100000.*6.112*exp(17.67*(temp-273.)/((temp-273.)+243.5)))) !% Partial pressure of h2o, Pa

	H2O=1e-6*6.022e23*es_T/(8.31*temp) !% H20, molecules cm^-3

	call photolysis(jval, zen, lsin) !calls the photolysis subroutine
	
	J_values(1:56)=jval(1:56) !photolysis constants vector

	tt=tt+timestep

	end subroutine photo_chem



	subroutine photolysis(jval, zen, lsin)
   	   
    integer nhv(22), lsin, i, l
   real*8 hvmat(22,40), hvmatb(22)
   real*8 jarray(80,510,56)

	! ARRAY DECLARATIONS:  J-VALUE INPUT ARRAY
      real*8 jparam(22)
	! ARRAY DECLARATIONS:  J-VALUE OUTPUT ARRAY
      real*8 jval(56)
	! ARRAY DECLARATIONS:  FOR CALCULATION OF SOLAR ZENITH ANGLE
	real*8 ut
    INTEGER idate 
    real*8 azim, zen

	l=l+1

	testreadhv=testreadhv+1
	do i=1,22
    jparam(i)=0.
    enddo

		
	if (testreadhv==1) then
	call readhv(lsin,nhv,hvmat, hvmatb, jarray)   

	end if	 
	rewind 89
	  
	!LONGITUDE (decimal degrees) (negative=west)

	!TIME (UTC, decimal hours, 0=midnight GMT, 17.5= 5:30 PM GMT)
    
	ut=t_from_start


	!INTEGER DATE (YYMMDD)
    idate=startdate

	call zenith(idate,ut,azim,zen)   



    jparam(20) = float(idate)
    if (jparam(20).lt.10000.) jparam(20)=jparam(20)+10000.


	!ZENITH ANGLE (degrees): 0=high noon, 90=sunset, >94=nighttime.
    jparam(1)=zen

	zenith_angle=zen

	!ALTITUDE (in kPa:  101.5=surface).  
	!(note OPTION in jval1.f = allows altitude in km)
    jparam(2)=pres/1000

	!OZONE COLUMN, DOBSON UNITS 
	!(330=standard.  Allowed range 250-410.  Preset vertical distribution)
    jparam(3)=330.

	! SO2 COLUMN, DOBSON UNITS
	jparam(4)=0.1

	! NO2 COLUMN, DOBSON UNITS
	jparam(5)=0.1

	! AEROSOL OPTICAL DEPTH
	jparam(6)=0.1

	! AEROSOL SINGLE S!ATTERING ALBEDO.
	jparam(7)= 0.85

	! SURFA!E ALBEDO
	jparam(8)= 0.3

	! SUMMED CLOUD OPTICAL DEPTH FOR CLOUDS ABOVE THE SPECIFIED ALTITUDE
	!   (0-100.  25 is reasonably !loudy.  0=!lear.)
	if (cloud==1) then
	jparam(9) = 20.
	else
	jparam(9) = 0.
	end if
	
	! SUMMED CLOUD OPTICAL DEPTH FOR CLOUDS BELOW THE SPE!IFIED ALTITUDE
	!   (0-100.  25 is reasonably !loudy.  0=!lear.  
	!     If altitude=surfa!e level, this had better be zero!)

	jparam(10) = 0.



	! WEIGHTED-AVERAGE ALTITUDE OF !LOUDS ABOVE THE !URRENT ALTITUDE
	!   In km, as distan!e above ground.  0-16 km.
	!   For multiple !louds, weighted average is weighted by opti!al 
	!    depth of ea!h !loud, !ounting only !louds-above.  
	jparam(11) = 1

	! WEIGHTED-AVERAGE ALTITUDE OF !LOUDS BELOW THE !URRENT ALTITUDE
	!   In km, as distan!e above the ground.  0-16 km.  
	!   For multiple !louds, weighted average is weighted by opti!al 
	!   depth of ea!h !loud, !ounting only !louds-below.  
	jparam(12) = 1.

	! TEMPERATURE FOR GIVEN ALTITUDE 
	!  This !an be either a spe!ifi! temperature (K) for the altitude 
	!   identified in jparam(2),
	!  Or it !an be the differen!e between the !urrent temperature and 
	!   the standard profile of atmospheri! temperatures used in the 
	!   j-value !al!ulation.
	!   (e.g. a value of 10 means 10 degrees warmer than standard)   
	jparam(13) = temp

	call jvalpro(nhv,hvmat, hvmatb, jarray,jparam, jval) 

	end subroutine photolysis
	
	
	end module