
function Dep_veloc=DEP_UHMA(temp, press, Dp, mass, land_use, wind_speed)


%  The parameterization and the parameter values used here are based on: 
%	Rannik et al, Interpretation of aerosol particle fluxes over a pine forest: 
%	Dry deposition and random errors, JGR, 2003

	fric_veloc = 0.4;		% median friction velocity [m/s]
	exponent = 2.5	;	
	wind_canopy = 1.5;		% wind speed at canopy height [m/s]
	gamma = 1.9		;		% coefficient of exponental decrease of wind speed inside canopy
	collection = 2.9;		% collection efficiency factor (from fig. 7; TRFE < 15%)
	dmin = 14.6e-8	;		% diameter of minimum in collection efficiency (from fig. 7; TRFE < 15%)
boltzmann = 1.3807e-23;
% ambient air properties
	air_mean_path = mean_free_path(temp, press);
	air_viscosity = viscosity_air(temp);
	air_density = dens_air(temp, press)	;	% [kg/m^3]     

    kn=knudsen(temp, press, Dp);
    
% Cunningham correction factor (based on Allen and Raabe (1982))
	corr_coeff = cunningham_correction(kn);

% particle gravitational settling velocity [m/s]
	settling_veloc = corr_coeff.*mass.*9.81./(6.*pi*air_viscosity.*Dp./2);
 
%aerodynamic resistance [s/m]  
	r_a = (wind_speed - wind_canopy)/fric_veloc^2;

% collection efficiency of particles due to Brownian diffusion
	diff_part = diffusion_particle(temp, corr_coeff, Dp);               	% diffusivity of particles [m^2/s]
	schmidt = air_viscosity./(air_density*diff_part);						% particle Schmidt number
	brownian = 1./3.*schmidt.^(-2./3.)	;							

%calculating prefactor (as a function of dmin) for empirical collection efficiency of particles
	coeff_dmin = 1. + air_mean_path/dmin*(2.514 + 0.8*...
        exp(-0.55*dmin/air_mean_path));
	diff_dmin = boltzmann*temp*coeff_dmin/(3.*pi*air_viscosity*dmin);
	schmidt_dmin = air_viscosity/(air_density*diff_dmin);
	deriv_coeff = -2.514*air_mean_path/dmin^2 - (air_mean_path/dmin...
        + 0.55)*0.8/dmin*exp(-0.55*dmin/air_mean_path);                     % derivative of Cunninghan correction factor 
	deriv_schmidt = schmidt_dmin*(1./dmin - 1./coeff_dmin*deriv_coeff);     % deriv. of Schmidt number
	prefactor = 2./9.*schmidt_dmin^(-5./3.)*deriv_schmidt/...
        (exponent*dmin^(exponent-1.));

	empirical = 4.*prefactor*(Dp/2).^exponent ;                              % empirical collection efficiency of particles

	eps = collection*(brownian + empirical)    ;                             %total collection efficiency of particles
	eps = sqrt(eps)	;

% canopy resistance [s/m]
	r_c = wind_canopy./(fric_veloc.^2.*eps).*((1. + eps.*...
        tanh(gamma.*eps))./(eps + tanh(gamma.*eps))) ;
	
	adep=0.4;
	bdep=20;
	z0=0.01;

air_viscosity=(1.832d-5*temp^1.5*406.4)/(5093*(temp+110.4))/1.85d3;
diff_part = boltzmann.*temp.*corr_coeff./(6*pi*air_viscosity*1.85d3.*Dp./2);
schmidt=air_viscosity./diff_part;
xx1=Dp.*(fric_veloc./z0./air_viscosity).^(1.d0/2.d0).*schmidt.^(1.e0/3.e0);
r_b=1./(diff_part./2./(Dp/2).*(adep.*xx1+bdep.*xx1.^3));
% deposition velocity [m/s]

	Dep_veloc = settling_veloc + 1./(r_a + r_c);

%St=ustar^2*sett_veloc/(9.81*kinemat_visc);
% if land_use==0
	Dep_veloc = (settling_veloc + 1./(r_a + r_b+r_a.*r_b.*settling_veloc));
 %end
