    close all
    clear all
    
    global saturation_conc ind_op N_limit diff_vol molar_gas
    
    %%%%%MAIN FRAMEWORK%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %                                                                     %
    %This framework defines size distribution and solves dynamics for     %
    %aerosol coagulation and growth via condensation of H2SO4.            %
    %Code developed by Peter Tunved, ITM/SU, 2015.                        %
    %                                                                     %
    %                                                                     %
    %                                                                     %
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    
    dt=30;                                                                 %timestep (s)
    duration=20;                                                            %Duration (h)
    
    
    Na=6.022e23;                                                            %Avogadros number
    Mh2o=18e-3;                                                             %Molar mass H2O g/mol
    Mh2so4=96*1e-3;                                                         %Molar mass H2SO4 kg/mol
    molec_h2o = Mh2o/Na;                                                    %Mass of one h2o molecule
    molec_h2so4=Mh2so4/Na;                                                  %Mass of one h2So4 molecule
    surf_ten =55.d-3;                                                       %Surface tension for H2SO4, N/m2
    rho_h2so4=1900;                                                         %Density of H2SO4, kg/m3
    molec_vol_h2so4=molec_h2so4/rho_h2so4;                                  %Volume of molecule, m3 

    
    p0=0;                                                                   %precipitation intensity (mm/h)
                                                                            %molecules/m3 (H2so4 in base case)
    ML_height=500;                                                          %Mixing layer heigth, m
    temp=263.15;                                                            %T (k)
    press=101325;                                                           %Pressure (Pa)
    rho_particle=2000;                                                      %density of particle (kg/m3)
    wind_speed=5;                                                           %wind speed (m/s)
    land_use=3 ;                                                            %Land use type (default broad leaf forest==3)
    N_limit=1e-10;                                                          %Lower Number conc limit for dynamics calculations
    ind_op=0
    
    nuc_coeff=1e-6;                                                         %Nucleation coefficient for use with activation type nucleation
    
    vapor_conc=1e11; 
    saturation_conc=0                                                      %Saturation vapor concentration (mol./m3) (*H2SO4*)
    
    vap_source=5e10;                                                        %Molecules/m3*s
    
    
    diff_vol = 51.96;                                                      %Diffusion volume of condensing gas
    molar_gas=96e-3;                                                       %kg/mol
    
    %%%%%%SIZE DISTRIBUTION%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    modes(1:4, 1)=[100e6, 600e6, 200e6, 0e6];                            %N conc of mode n (1/m3)
    modes(1:4, 2)=[1.9, 1.8, 1.6, 2];                                       %GSD -"-
    modes(1:4, 3)=[10,30, 120, 700];                                          %Dg -"- (nm)
    nobins=30;                                                              %number of bins in SD
    dlogdp=0.12;                                                             %dlogdp of SD
    Dp=1e-9*10.^(dlogdp*[0:1:nobins]);                                      %sizerange over which N is calculated
    N=mode_eval_1(modes, Dp)*dlogdp;                                        %Number concentration per bin (1/m3)
    mass=rho_particle*pi./6*Dp.^3;                                          %mass per bin (kg)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


      N_ini=N;
    
    ind=0;
    t_temp=0;
    for t=0:dt:duration*3600
        t_temp=t_temp+dt;
        
     
 t
      
   
        [N_cond, CS]=CONDENSATION(Dp, N, vapor_conc, dt, nobins,...         %Calling condensation routine
        temp, press);
       
        if vapor_conc<0
            vapor_conc=0;
        end
       N=N_cond;                                                           %Growth solved within routine, N assigned from N_cond
        
       
       
          vapor_conc=vapor_conc-CS*dt+vap_source*dt*abs((t_temp-90)/90);                                                                   
        
       n_coag=COAGULATION(N, Dp, nobins, temp, press, mass);               %Calling coagulation routine
       ncoag(isnan(n_coag))=0;                                             %unprofessional fix
       N=N+n_coag*dt;                                                      %dN/dt for coagulation
   
       Vd=DRY_DEP(temp, press, wind_speed, land_use, Dp, mass);
       %Vd=DEP_UHMA(temp, press, Dp, mass, land_use, wind_speed);
        
    
        N=N-Vd.*N./ML_height*dt;

       
       if t/3600>10 & t/3600<2                                              %Just specify when it should rain....
           p0=5;
       else
           p0=0;
       end
     
       if p0>0
       scav_dp=BELOW_CLOUD_SCAVENGING(p0, temp, press, N, Dp, nobins,...
         rho_particle);                                                    %scav_coefficinet, s-1
         N=N-scav_dp.*N.*dt;
       end
       
       
        [n_nuc]=NUCLEATION(vapor_conc, nuc_coeff, molec_vol_h2so4,...       %Calls activation type nucleation
            (Dp(1)/2));
        
           N(1)=N(1)+n_nuc*dt;
           vapor_conc=vapor_conc-n_nuc*dt
     
        if t_temp/1>1  
                  ind=ind+1;
                  N_out(ind, 1:4)=[t, nansum(nansum(N.*Dp.^3)), vapor_conc, n_nuc];                     %time dependent int
                  N_dist(ind, 1:nobins+1)=1e-6*N/dlogdp; 
                  t_temp=0
                    plot(sum(N.*Dp.^3), '.')
         
        end
    end
  plot(sum(N.*Dp.^3))
    
    figure(1)
    semilogx(Dp, N_ini, Dp, N)
    figure(2)
    semilogx(Dp, N_dist(:,:), 'k')
    figure(3)
    pcolor(N_out(:, 1), Dp, log10(abs(N_dist))')
    set(gca, 'yscale', 'log')
    caxis([0, 4])
    shading flat