
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Simplified way to calculate quasi laminar resistance as function of 
%Particle Size, Temp, Pressure, Wind Speed and land use types
%
%
%Created by Peter Tunved, ITM/SU, 2015
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function  Rb=Quasi_laminar_resistance(Sc, land_use, sett_veloc,...
    kinemat_visc, Dp, temp, press);  


if nargin==7

                                               

Ustar_para=load('Ustar_Zhang2003.dat');                                     %Ustar for different vegetation("land use") 
Ustar_Zhang2003_Day=Ustar_para(:, 1);                                       %types during night and day

Ustar_Zhang2003_Night=Ustar_para(:, 1);

ustar=Ustar_Zhang2003_Day(land_use);





St=N_Stokes(sett_veloc, kinemat_visc, ustar);



Rb=1./(ustar.*(Sc.^(-2/3)+10.^(-3./St)));          %Quasi laminar resistance(aerosols over flat type land (desert or similar))


omega=0.5;
 
Rb=1./(ustar.*(1+0.24*(omega/ustar.^2))*(Sc.^(-2/3)+10.^(-3./St))); 
	

else
    
    error('Function requires input of Schmidt number, land use type, settling velocity and kinematic viscosity, Dp,Temp (K) and pressure (Pa)')
end
end

