%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%Function to estimate Aerodynamical Resistance as function of windspeed 
%
%Friction velocity used from tabulated values in Zhang et aln 2003. Depends
%on landuse type and day/nights.
%Created by Peter Tunved, ITM/SU, 2015
%
%
%Usage: Ra=aerodynamical_resistance(wind_speed, land_use)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [Ra, units]=aerodynamical_resistance(wind_speed, land_use)


if nargin==2
%land_use=3                                                                 %broad leaf forest as default

Uref=0;
Ustar_para=load('Ustar_Zhang2003.dat');
Ustar_Zhang2003_Day=Ustar_para(:, 1);
Ustar_Zhang2003_Night=Ustar_para(:, 1);

Ra = (wind_speed-Uref)/Ustar_Zhang2003_Day(land_use)^2;                     %Day as default (From paper by Zhang et al 2003)
units='s/m';

else
    error('Function requires input of windspeed in m/s and land use type')
end
end
