%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function to calculate the kelvin effect on vapour pressure over particles
%
%Utilize input of surface tension of liquid, molecular volume, radius of
%particle and temperature
%
%Peter Tunved, ITM/SU, 2015
%
%Usage: [kelvin, unit]=kelvin_effect(surface_tension, molec_vol, ...
%temp, radius)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [kelvin, unit]=kelvin_effect(molec_vol, temp, radius)

if nargin==3
   boltzmann = 1.3807e-23;
 
	surf_ten=surface_tension(temp);
    
	exponent=2.*surf_ten.*molec_vol;
	exponent=exponent./(boltzmann*temp.*radius);
	kelvin=exp(exponent);
    unit='unitless';
    
else
    error('Function need input of  molecular volume, temperature and particle radius')
  end 