%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%Calculates the Marshall Palmer droplet distribution as function of rain
%intensity, p0 over the size range specified by Ddrops).
%
%
%Peter Tunved, ITM/SU, 2015
%
%Usage: [N_Dp, units]=marshall_palmer(p0, Ddrops)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [N_Dp, units]=marshall_palmer(p0, Ddrops)

if nargin==2
n0=8000;                                                                     %Droplets m-3

gauss=4.1*p0^-0.21;
N_Dp=p0*n0*exp(-gauss.*Ddrops);                                              %Droplet distribution 

units='m-3 mm-1';
else
    error('Function needs input of p0, mm and Ddrops, m-1)')    
end
