%
%
% Function to calculate the relaxation time tau (s) as function of temperature
% T(K), pressure p(Pa), particle diameter (Dp) and density of particle rho_p (kg/m3).
% See equation 8.38 in Seinfeld & Pandis for details.
% 
% St is a measure of how quickly a particle adopt to changes in flow
% conditions.
%
% Usage: tau=relaxation_time(temp, press, Dp, rho_p)
%
%
% Peter Tunved, ITM/SU, 2011
%
%

function tau=relaxation_time(temp, press, Dp, rho_p)

if nargin==4
    rho_w=1000;
    tau=((rho_p-dens_air(temp, press))*Dp^2*slip_correct(temp, press, Dp))/(18*viscosity_air(temp));
    
else
    
    error('Function needs input of temperature T(K), pressure p(Pa), particle diameter Dp(m) and particle density rho_p(kg/m3)')
    
end