%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Function to calculate the scavenging efficiency of a particle of diamater 
% Dp by a droplet of diamater Dd. See Seinfeldt and Pandis, eq. 20.56 for 
% details. Requires input of T(K), P(Pa), Dp(part. diameter, m), Dd(drop.
% diameter, m), rho_p(dens. part, kg/m3), Re1(Reynolds number of Droplet),
% vt1(terminal velocity of drop, m/s)
% 
%
% Peter tunved, ITM/SU, 2011
%
%
%Usage: [E_Dp_Dd,brown, inter, impact]=scav_eff(temp, press, Dp, Dd,...
%rho_p, Re1, vt1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [E_Dp_Dd,brown, inter, impact]=scav_eff(temp, press, Dp, Dd, rho_p, Re1, vt1)


if nargin==7
    rho_w=1000;
   % [Re1,vt1]=terminal_v(temp, press, Dd, rho_w);                           %For rain drops V
   % [Re2,vt2]=terminal_v(temp, press, Dp, rho_p);                           %For Aerosol particle V
    
    
    Sstar=(1.2+(1/12)*log(1+Re1))/(1+log(1+Re1));                           %For Re raindrops V
    
  
    %stoke_numb tested
       
    [air_density]=density_air(temp, press);                                %Density of air, f(P, T), 'kg/m3' V
    
    [visc_air]=viscosity_air(temp);                                        %viscosity of air, f(T), 'Pa*s' V
    visc_h2o=1e-1;
    omega=visc_h2o/visc_air;
          
    [Kn]=knudsen(temp, press, Dp);                                         %Knudsen number
    
    [corr]=cunningham_correction(Kn);                                      %Cunningham correction   
    [diff_Dp]=diffusion_particle(temp, corr, Dp);                          %Diffusion particle (f(T, CC, Visc, Dp)), 'm2*s'
    
    [Sc]=schmidt(air_density, diff_Dp, visc_air); 
    
    A=(4/(Re1.*Sc));                                                        %Brownian term1
    B=(1+0.4*Re1^0.5*Sc^(1/3)+0.16*Re1^0.5*Sc^0.5);                         %Brownian term2
    C=4*(Dp/Dd)*(omega^-1+(1+2*Re1^0.5)*(Dp/Dd));                           %interception term
    
    
    Rel_time=relaxation_time(temp, press, Dp, rho_p);                       %relaxation time
    
    St=2*Rel_time*(vt1)/Dd;                                                 %Stokes number

    if St>1.2
    D=((St-Sstar)/(St-Sstar+2/3))^(3/2)*(rho_p/rho_w)^(1/2);                %Impaction term
    else
   D=0;
end
 

    E_Dp_Dd=A*B+C+D;                                                        %total scavengning
    if E_Dp_Dd>1
        E_Dp_Dd=1;
    end
    brown=A*B;
    inter=C;
    impact=D;



    
else
    
    error('somethings shitty')
end