
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculates settling velocity based on temperature, pressure, mass and
%radius.
%Peter Tunved, ITM/SU, 2015
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function settl_veloc=settling_velocity(Dp, temp, press, mass)

g=9.81;                                                                     %Gravitation m/s2

[Kn, units]=knudsen(temp, press, Dp);                                       %Knudsen number, Kn
[corr, units]=cunningham_correction(Kn);                               %Cunningham correction factor
[visc_air, units]=viscosity_air(temp) ;                                      %Air viscosity


settl_veloc=corr.*mass.*g./(3.*pi*visc_air.*Dp/2);              %settling velocity, m/s