%
%
% Function to calculate the stokes number (St) as function of temperature
% T(K), pressure p(Pa), particle diameter (Dp), flow speed (u0) and
% characteristic lenght of flow L(m). See equation 8.105 in Seinfeld & Pandis
% for details.
% St is a measure of how quickly a particle adopt to changes in flow
% conditions.
%
% St is a measure of how quickly a particle adopt to changes in flow
% conditions.
% Usage: St=stoke_numb(temp, press, Dp, u0, L)
%
%
% Peter Tunved, ITM/SU, 2011
%
%

function St=stoke_numb(temp, press, Dp, u0, rho_p)


if nargin==5
   
    St=(2*relaxation_time(temp, press, Dp, rho_p)*u0)/Dp; %eq 8.105 Seinfeld&Pandis
    
else
    
    error('Function needs input of temperature T(K), pressure p(Pa), diameter of particle Dp(m), fluid velocity u0 (m/s) and charachteristic flow lenght L(m)')
    
end