%
%
% Function to calculate the stopping distance (m) for a particle as function of temperature
% T(K), pressure p(Pa), particle diameter (Dp), density of particle rho_p (kg/m3)
% and initial velocity of particle v(m/s).
% See equation 8.38 in Seinfeld & Pandis for details.
% 
% St is a measure of how quickly a particle adopt to changes in flow
% conditions.
%
% Usage: Sp=stopping_distance(temp, press, Dp, rho_p, v)
%
%
% Peter Tunved, ITM/SU, 2011
%
%

function [Sp, units]=stopping_distance(temp, press, Dp, rho_p, v)


if  nargin==5
    units='m';
    Sp=relaxation_time(temp, press, Dp, rho_p)*v;
    
else
      error('Function needs input of temperature T(K), pressure p(Pa), particle diameter Dp(m) and particle density rho_p(kg/m3)')
  end
