%
%
%
% Function to calculate the terminal velocity and Reynolds number of a particle depening on temp (K) , 
% pressure (Pa), particle diamater (m) and density of particle rho_p (kg/m3):
% vt=(4*g*Dp*Cc*rho_part/(3*Cd*rho)) (m/s)
% 
% Usage: [Re,vt]=terminal_v(temp, press, Dp, rho_p)
%
% Peter Tunved, ITM/SU, 2011
%
%CHK_OK


function [vt, Re, units]=terminal_v(temp, press, Dp, rho_p)

g=9.81; % (m/s2)

if nargin==4
    units='m/s';
    %first guess
    
    Cd_d=1;
    vt_old=1000;
    vt=((4*g*Dp.*slip_correct(temp, press, Dp).*rho_p)./(3*Cd_d.*dens_air(temp, press))).^(1/2); %(m/s)
 
    while abs((vt-vt_old)/vt_old)>1e-9
        

       
        vt_old=vt;
         
        Cd_d=drag_coeff(Reynolds(Dp, temp, press, vt));
        vt=((4.*g.*Dp.*slip_correct(temp, press, Dp).*rho_p)./(3*Cd_d.*dens_air(temp, press))).^(1/2); %(m/s)
   
    end

else
     error('Function needs input of temperature T (K),  pressure p(Pa), particle diamater (m) and density of particle (kg/m3)')
end

if nargout<2
    Re=Reynolds(Dp, temp, press, vt);
elseif nargout==2
       Re=Reynolds(Dp, temp, press, vt);
       vt=vt;
end

